### Plugin Manager

Browse a selection of freely available scripts, plug-ins, and modules in “Window” → “Plugin Manager”.

At the top of the window are two groups of filters.
Filter the extensions by whether they are installed with the “All”, “Installed”, “Not Installed” buttons.
Filter by extension type with the “Plugins”, “Scripts”, “Modules” buttons.
Enter a keyword in the search field located in the top-right of the window to search by extension name, description, or the name of the extension vendor.

Install an extension by clicking the green Install button beside it.
Uninstall an extension by clicking its Remove button.
Glyphs needs to be relaunched for newly installed plug-ins and modules to be available.
Newly installed scripts can be loaded without relaunching Glyphs by holding down the Option key and choosing “Script” → “Reload Scripts” (Cmd-Opt-Shift-Y).
Updated versions of extensions are installed automatically.

Enlarge preview images to their full size by clicking on them.
Click the gray link below the extension description to view its website.
Some extension vendors accept donations via  PayPal and  Ko-fi.
Click the icon to open the donation page.

New extensions are added regularly to the Plugin Manager.
Open a pull request at the Glyphs plug-in repository to add a new entry or contact the Glyphs team on the Glyphs forum or directly per email.
See Creating Scripts and Creating Plug-ins for details on creating new extensions.

Plugin Manager lists extensions from the main repository, accessible to all users.
Add alternative repositories as described in Alternate Plugin Repositories.
These will also show up in the Plugin Manager, but only for users that have registered the same alternative repository in their Glyphs setup.